==> oe-like-jquery-1.0.13.tgz: package/œ.js <==
function _œ(id) {

  // About object is returned if there is no 'id' parameter
  var about = {
    Version: "1.0.13",
    Author: "Landon Gravat",
    Created: "Fall 2017",
    Updated: "25 October 2017"
  };

  if (id) {

    // Avoid clobbering the window scope:
    // return a new _ object if we're in the wrong scope
    if (window === this) {
      return new _œ(id);
    }

    // We're in the correct object scope:
    // Init our element object and return the object
    this.e = document.getElementById(id);
    return this;
  } else {
    // No 'id' parameter was given, return the 'about' object
    return about;
  }
}
_œ.prototype = {
  hide: function() {
    var len = this.length;

    // Here we simply loop through our object (this) and set the css to display none. 
    while (len--) {
      this.e.style.visibility = 'hidden';
    }

    // If you want to chain methods, it's important to return this.
    return this;
  },

  // This method shows the hidden, selected elements
  show: function() {
    var len = this.length;

    while (len--) {
      this.e.style.visibility = 'visible';
    }

    return this;
  },

  on: function(evt, fn) {
    var len = this.length;
    while (len--) {
      if (document.addEventListener) {
        this.e.addEventListener(evt, fn, false);
      } else if (document.attachEvent) {
        this.e.attachEvent("on" + evt, fn);
      } else {
        this.e["on" + evt] = fn;
      }
    }
    return this;
  },

  bgcolor: function(color) {
    this.e.style.background = color;
    return this;
  },

  val: function(newval) {
    this.e.value = newval;
    return this;
  },

  toggle: function() {
    if (this.e.style.visibility !== 'hidden') {
      this.e.style.visibility = 'hidden';
    } else {
      this.e.style.visibility = 'visible';
    }
    return this;
  },

  size: function(height, width) {
    this.e.style.height = height + 'px';
    this.e.style.width = width + 'px';
    return this;
  },

  click: function(callback) {
    this.e.addEventListener('click', callback, false);
    return this;
  },

  css: function(attr, val) {


    this.e.style[attr] = val;


    return this;
  },
}

==> oe-like-jquery-1.1.0.tgz: package/œ.js <==
function _œ(id) {

  // About object is returned if there is no 'id' parameter
  var about = {
    Version: "1.0.13",
    Author: "Landon Gravat",
    Created: "Fall 2017",
    Updated: "25 October 2017"
  };

  if (id) {

    // Avoid clobbering the window scope:
    // return a new _ object if we're in the wrong scope
    if (window === this) {
      return new _œ(id);
    }

    // We're in the correct object scope:
    // Init our element object and return the object
    this.e = document.getElementById(id);
    return this;
  } else {
    // No 'id' parameter was given, return the 'about' object
    return about;
  }
}
_œ.prototype = {
  addListener: function(event, callback) {
    this.e.addEventListener(event, callback, false);
  },
  
  hide: function() {
    this.e.style.visibility = 'hidden';
    return this;
  },

  // This method shows the hidden, selected elements
  show: function() {
    this.e.style.visibility = 'visible';
    return this;
  },

  on: function(evt, fn) {
    var len = this.length;
    while (len--) {
      if (document.addEventListener) {
        this.e.addEventListener(evt, fn, false);
      } else if (document.attachEvent) {
        this.e.attachEvent("on" + evt, fn);
      } else {
        this.e["on" + evt] = fn;
      }
    }
    return this;
  },

  bgcolor: function(color) {
    this.e.style.background = color;
    return this;
  },

  val: function(newval) {
    this.e.value = newval;
    return this;
  },

  toggle: function() {
    if (this.e.style.visibility !== 'hidden') {
      this.e.style.visibility = 'hidden';
    } else {
      this.e.style.visibility = 'visible';
    }
    return this;
  },

  size: function(height, width) {
    this.e.style.height = height + 'px';
    this.e.style.width = width + 'px';
    return this;
  },

  click: function(callback) {
    this.addListener('click', callback);
    return this;
  },

  css: function(attr, val) {
    this.e.style[attr] = val;
    return this;
  },
  
  // New as of version 1.1
  mouseOver: function(callback){
    this.addListener('onMouseOver', callback);
    return this;
  },
  
  keyDown: function(callback) {
    this.addListener('keydown', callback);
    return this;
  },
  
  mouseWheel: function(callback) {
    this.addListener('wheel', callback);
    return this;
  },
  
  doubleClick: function(callback) {
    this.addListener('dblclick', callback);
    return this;
  }
}
